@@ -21,6 +21,7 @@ const CopyWebpackPlugin = require('copy-webpack-plugin');
 const GenerateWebLabelsPlugin = require('./webpack-plugins/generate-weblabels-webpack-plugin');
 const ProgressBarPlugin = require('progress-bar-webpack-plugin');
 const DumpHighlightjsLanguagesDataPlugin = require('./webpack-plugins/dump-highlightjs-languages-data-plugin');
+const ESLintPlugin = require('eslint-webpack-plugin');
 
 // are we running webpack-dev-server ?
 const isDevServer = process.argv.find(v => v.includes('serve')) !== undefined;
@@ -43,9 +44,6 @@ fs.readdirSync(bundlesDir).forEach(file => {
 // common loaders for css related assets (css, sass)
 const cssLoaders = [
   MiniCssExtractPlugin.loader,
-  {
-    loader: 'cache-loader'
-  },
   {
     loader: 'css-loader',
     options: {
@@ -65,7 +63,8 @@ const cssLoaders = [
               'rules': {
                 'indentation': 4,
                 'font-family-no-missing-generic-family-keyword': null,
-                'no-descending-specificity': null
+                'no-descending-specificity': null,
+                'selector-class-pattern': null
               },
               'ignoreFiles': ['node_modules/**/*.css',
                               'assets/src/thirdparty/**/*.css']
@@ -87,7 +86,7 @@ const cssLoaders = [
 module.exports = {
   // use caching to speedup incremental builds
   cache: {
-    type: 'memory'
+    type: 'filesystem'
   },
   // set mode to development
   mode: 'development',
@@ -114,7 +113,10 @@ module.exports = {
     port: devServerPort,
     // enable to serve static assets not managed by webpack
     static: {
-      directory: path.resolve('./')
+      directory: path.resolve('./'),
+      watch: {
+        ignored: /node_modules/
+      }
     },
     // we do not use hot reloading here (as a framework like React needs to be used in order to fully benefit from that feature)
     // and prefer to fully reload the frontend application in the browser instead
@@ -153,22 +155,6 @@ module.exports = {
   // module import configuration
   module: {
     rules: [
-      {
-      // Preprocess all js files with eslint for consistent code style
-      // and avoid bad js development practices.
-        enforce: 'pre',
-        test: /\.js$/,
-        exclude: /node_modules/,
-        use: [{
-          loader: 'eslint-loader',
-          options: {
-            configFile: path.join(__dirname, '.eslintrc'),
-            ignorePath: path.join(__dirname, '.eslintignore'),
-            cache: true,
-            emitWarning: true
-          }
-        }]
-      },
       {
       // Use babel-loader in order to use es6 syntax in js files
       // but also advanced js features like async/await syntax.
@@ -177,9 +163,6 @@ module.exports = {
         test: /\.js$/,
         exclude: /node_modules/,
         use: [
-          {
-            loader: 'cache-loader'
-          },
           {
             loader: 'babel-loader',
             options: {
@@ -432,7 +415,15 @@ module.exports = {
       format: chalk.cyan.bold('webpack build of swh-web assets') + ' [:bar] ' + chalk.green.bold(':percent') + ' (:elapsed seconds)',
       width: 50
     }),
-    new DumpHighlightjsLanguagesDataPlugin()
+    new DumpHighlightjsLanguagesDataPlugin(),
+    // Process all js files with eslint for consistent code style
+    // and avoid bad js development practices.
+    new ESLintPlugin({
+      overrideConfigFile: path.join(__dirname, '.eslintrc'),
+      ignorePath: path.join(__dirname, '.eslintignore'),
+      cache: true,
+      emitWarning: true
+    })
   ],
   // webpack optimizations
   optimization: {
