@@ -3,9 +3,15 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+import os
+
 from swh.web.api.apidoc import api_doc, format_docstring
 from swh.web.api.apiurls import api_route
-from swh.web.auth.utils import privileged_user
+from swh.web.auth.utils import (
+    API_SAVE_ORIGIN_PERMISSION,
+    SWH_AMBASSADOR_PERMISSION,
+    privileged_user,
+)
 from swh.web.common.origin_save import (
     create_save_origin_request,
     get_savable_visit_types,
@@ -14,11 +20,13 @@ from swh.web.common.origin_save import (
 
 
 def _savable_visit_types():
-    visit_types = sorted(get_savable_visit_types())
     docstring = ""
-    for visit_type in visit_types[:-1]:
-        docstring += f"**{visit_type}**, "
-    docstring += f"and **{visit_types[-1]}**"
+    if os.environ.get("DJANGO_SETTINGS_MODULE") != "swh.web.settings.tests":
+        visit_types = sorted(get_savable_visit_types())
+        docstring = ""
+        for visit_type in visit_types[:-1]:
+            docstring += f"**{visit_type}**, "
+        docstring += f"and **{visit_types[-1]}**"
     return docstring
 
 
@@ -85,6 +93,8 @@ def api_save_origin(request, visit_type, origin_url):
         :>json string visit_status: the status of the visit, either **full**,
             **partial**, **not_found** or **failed** if a visit occurred, null
             otherwise.
+        :>json string note: optional note giving details about the save request,
+            for instance why it has been rejected
 
         :statuscode 200: no error
         :statuscode 400: an invalid visit type or origin url has been provided
@@ -98,7 +108,10 @@ def api_save_origin(request, visit_type, origin_url):
         sor = create_save_origin_request(
             visit_type,
             origin_url,
-            privileged_user(request),
+            privileged_user(
+                request,
+                permissions=[SWH_AMBASSADOR_PERMISSION, API_SAVE_ORIGIN_PERMISSION],
+            ),
             user_id=request.user.id,
             **data,
         )
