@@ -13,16 +13,8 @@ from django.shortcuts import render
 from django.utils.html import escape
 
 from swh.model.hashutil import hash_to_bytes
-from swh.model.identifiers import (
-    CONTENT,
-    DIRECTORY,
-    RELEASE,
-    REVISION,
-    SNAPSHOT,
-    CoreSWHID,
-    ObjectType,
-)
 from swh.model.model import Snapshot
+from swh.model.swhids import CoreSWHID, ObjectType
 from swh.web.browse.utils import (
     content_display_max_size,
     format_log_entries,
@@ -488,7 +480,7 @@ def get_snapshot_context(
             )
 
         visit_url = reverse("browse-origin-directory", query_params=query_params)
-        visit_info["url"] = visit_url
+        visit_info["url"] = directory_url = visit_url
 
         branches_url = reverse("browse-origin-branches", query_params=query_params)
 
@@ -497,6 +489,7 @@ def get_snapshot_context(
         assert snapshot_id is not None
         branches, releases, aliases = get_snapshot_content(snapshot_id)
         url_args = {"snapshot_id": snapshot_id}
+        directory_url = reverse("browse-snapshot-directory", url_args=url_args)
         branches_url = reverse("browse-snapshot-branches", url_args=url_args)
 
         releases_url = reverse("browse-snapshot-releases", url_args=url_args)
@@ -619,6 +612,7 @@ def get_snapshot_context(
                 revision_info["message_header"] = ""
 
     snapshot_context = SnapshotContext(
+        directory_url=directory_url,
         branch=branch_name,
         branch_alias=branch_name in aliases,
         branches=branches,
@@ -799,6 +793,7 @@ def browse_snapshot_directory(
     swh_objects = []
     vault_cooking = {}
     revision_found = True
+
     if sha1_git is None and revision_id is not None:
         try:
             archive.lookup_revision(revision_id)
@@ -806,16 +801,22 @@ def browse_snapshot_directory(
             revision_found = False
 
     if sha1_git is not None:
-        swh_objects.append(SWHObjectInfo(object_type=DIRECTORY, object_id=sha1_git))
+        swh_objects.append(
+            SWHObjectInfo(object_type=ObjectType.DIRECTORY, object_id=sha1_git)
+        )
         vault_cooking.update(
             {"directory_context": True, "directory_swhid": f"swh:1:dir:{sha1_git}",}
         )
-    if revision_found:
-        swh_objects.append(SWHObjectInfo(object_type=REVISION, object_id=revision_id))
+    if revision_id is not None and revision_found:
+        swh_objects.append(
+            SWHObjectInfo(object_type=ObjectType.REVISION, object_id=revision_id)
+        )
         vault_cooking.update(
             {"revision_context": True, "revision_swhid": f"swh:1:rev:{revision_id}",}
         )
-    swh_objects.append(SWHObjectInfo(object_type=SNAPSHOT, object_id=snapshot_id))
+    swh_objects.append(
+        SWHObjectInfo(object_type=ObjectType.SNAPSHOT, object_id=snapshot_id)
+    )
 
     visit_date = None
     visit_type = None
@@ -825,10 +826,12 @@ def browse_snapshot_directory(
 
     release_id = snapshot_context["release_id"]
     if release_id:
-        swh_objects.append(SWHObjectInfo(object_type=RELEASE, object_id=release_id))
+        swh_objects.append(
+            SWHObjectInfo(object_type=ObjectType.RELEASE, object_id=release_id)
+        )
 
     dir_metadata = DirectoryMetadata(
-        object_type=DIRECTORY,
+        object_type=ObjectType.DIRECTORY,
         object_id=sha1_git,
         directory=sha1_git,
         nb_files=nb_files,
@@ -983,12 +986,25 @@ def browse_snapshot_content(
 
     content_checksums = content_data.get("checksums", {})
 
-    swh_objects = [
-        SWHObjectInfo(object_type=CONTENT, object_id=content_checksums.get("sha1_git")),
-        SWHObjectInfo(object_type=DIRECTORY, object_id=directory_id),
-        SWHObjectInfo(object_type=REVISION, object_id=revision_id),
-        SWHObjectInfo(object_type=SNAPSHOT, object_id=snapshot_id),
-    ]
+    sha1_git = content_checksums.get("sha1_git")
+
+    swh_objects = []
+
+    if sha1_git is not None:
+        swh_objects.append(
+            SWHObjectInfo(object_type=ObjectType.CONTENT, object_id=sha1_git)
+        )
+    if directory_id is not None:
+        swh_objects.append(
+            SWHObjectInfo(object_type=ObjectType.DIRECTORY, object_id=directory_id)
+        )
+    if revision_id is not None:
+        swh_objects.append(
+            SWHObjectInfo(object_type=ObjectType.REVISION, object_id=revision_id)
+        )
+    swh_objects.append(
+        SWHObjectInfo(object_type=ObjectType.SNAPSHOT, object_id=snapshot_id)
+    )
 
     visit_date = None
     visit_type = None
@@ -998,10 +1014,12 @@ def browse_snapshot_content(
 
     release_id = snapshot_context["release_id"]
     if release_id:
-        swh_objects.append(SWHObjectInfo(object_type=RELEASE, object_id=release_id))
+        swh_objects.append(
+            SWHObjectInfo(object_type=ObjectType.RELEASE, object_id=release_id)
+        )
 
     content_metadata = ContentMetadata(
-        object_type=CONTENT,
+        object_type=ObjectType.CONTENT,
         object_id=content_checksums.get("sha1_git"),
         sha1=content_checksums.get("sha1"),
         sha1_git=content_checksums.get("sha1_git"),
@@ -1175,13 +1193,15 @@ def browse_snapshot_log(request, snapshot_id=None, origin_url=None, timestamp=No
         revision_metadata["origin visit type"] = visit_info["type"]
 
     swh_objects = [
-        SWHObjectInfo(object_type=REVISION, object_id=revision_id),
-        SWHObjectInfo(object_type=SNAPSHOT, object_id=snapshot_id),
+        SWHObjectInfo(object_type=ObjectType.REVISION, object_id=revision_id),
+        SWHObjectInfo(object_type=ObjectType.SNAPSHOT, object_id=snapshot_id),
     ]
 
     release_id = snapshot_context["release_id"]
     if release_id:
-        swh_objects.append(SWHObjectInfo(object_type=RELEASE, object_id=release_id))
+        swh_objects.append(
+            SWHObjectInfo(object_type=ObjectType.RELEASE, object_id=release_id)
+        )
         browse_rel_link = gen_release_link(release_id)
         revision_metadata["release"] = release_id
         revision_metadata["context-independent release"] = browse_rel_link
