@@ -4,13 +4,13 @@
 # See top-level LICENSE file for more information
 
 from django.shortcuts import redirect, render
+from django.urls import resolve
 
 from swh.web.browse.browseurls import browse_route
 from swh.web.browse.snapshot_context import (
     browse_snapshot_branches,
     browse_snapshot_content,
     browse_snapshot_directory,
-    browse_snapshot_log,
     browse_snapshot_releases,
     get_snapshot_context,
 )
@@ -20,6 +20,15 @@ from swh.web.common.origin_visits import get_origin_visits
 from swh.web.common.utils import format_utc_iso_date, parse_iso8601_date_to_utc, reverse
 
 
+def redirect_to_new_route(request, new_route):
+    request_path = resolve(request.path_info)
+    # Send all the url_args and the request_args as query params
+    # eg /origin/<url:url-val>/log?path=test
+    # will be send as /log?url=<url-val>&path=test
+    args = {**request_path.kwargs, **{k: v for k, v in request.GET.items()}}
+    return redirect(reverse(new_route, query_params=args), permanent=True,)
+
+
 @browse_route(
     r"origin/directory/", view_name="browse-origin-directory",
 )
@@ -111,17 +120,15 @@ def origin_content_browse_legacy(request, origin_url, path=None, timestamp=None)
     r"origin/log/", view_name="browse-origin-log",
 )
 def origin_log_browse(request):
-    """Django view that produces an HTML display of revisions history (aka
+    """
+    This route is deprecated; use http:get:`/browse/snapshot/log` instead
+
+    Django view that produces an HTML display of revisions history (aka
     the commit log) associated to a software origin.
 
     The URL that points to it is :http:get:`/browse/origin/log/`
     """
-    return browse_snapshot_log(
-        request,
-        origin_url=request.GET.get("origin_url"),
-        snapshot_id=request.GET.get("snapshot"),
-        timestamp=request.GET.get("timestamp"),
-    )
+    return redirect_to_new_route(request, "browse-snapshot-log")
 
 
 @browse_route(
@@ -130,7 +137,10 @@ def origin_log_browse(request):
     view_name="browse-origin-log-legacy",
 )
 def origin_log_browse_legacy(request, origin_url, timestamp=None):
-    """Django view that produces an HTML display of revisions history (aka
+    """
+    This route is deprecated; use http:get:`/browse/snapshot/log` instead
+
+    Django view that produces an HTML display of revisions history (aka
     the commit log) associated to a software origin.
 
     The URLs that point to it are
@@ -138,12 +148,7 @@ def origin_log_browse_legacy(request, origin_url, timestamp=None):
     :http:get:`/browse/origin/(origin_url)/visit/(timestamp)/log/`
 
     """
-    return browse_snapshot_log(
-        request,
-        origin_url=origin_url,
-        snapshot_id=request.GET.get("snapshot"),
-        timestamp=timestamp,
-    )
+    return redirect_to_new_route(request, "browse-snapshot-log",)
 
 
 @browse_route(
