@@ -44,10 +44,7 @@ DEFAULT_CONFIG = {
     ),
     "search_config": (
         "dict",
-        {
-            "metadata_backend": "swh-indexer-storage",  # or "swh-search"
-            "enable_ql": False,
-        },
+        {"metadata_backend": "swh-indexer-storage",},  # or "swh-search"
     ),
     "log_dir": ("string", "/tmp/swh/log"),
     "debug": ("bool", False),
@@ -90,7 +87,7 @@ DEFAULT_CONFIG = {
     "vault": ("dict", {"cls": "remote", "args": {"url": "http://127.0.0.1:5005/",}}),
     "scheduler": ("dict", {"cls": "remote", "url": "http://127.0.0.1:5008/"}),
     "development_db": ("string", os.path.join(SETTINGS_DIR, "db.sqlite3")),
-    "test_db": ("string", os.path.join(SETTINGS_DIR, "testdb.sqlite3")),
+    "test_db": ("dict", {"name": "swh-web-test"}),
     "production_db": ("dict", {"name": "swh-web"}),
     "deposit": (
         "dict",
