@@ -93,6 +93,12 @@ listed_origins = {
             "info": "releases from the GNU project (as of August 2015)",
             "search_pattern": "gnu",
         },
+        {
+            "type": "heptapod",
+            "info_url": "https://heptapod.net/",
+            "info": "public repositories from multiple Heptapod instances",
+            "search_pattern": "heptapod",
+        },
         {
             "type": "launchpad",
             "info_url": "https://launchpad.net",
@@ -115,6 +121,12 @@ listed_origins = {
             "info": "public packages from the package registry for javascript",
             "search_pattern": "https://www.npmjs.com",
         },
+        {
+            "type": "opam",
+            "info_url": "https://opam.ocaml.org/",
+            "info": "public packages from the source-based package manager for OCaml",
+            "search_pattern": "opam+https://opam.ocaml.org/",
+        },
         # apart our forge, most phabricator origins have not been archived
         # while they have been listed so do not display those type of origins
         # until new listing processes have been executed and origins loaded
@@ -167,6 +179,14 @@ legacy_origins = {
             "search_pattern": "googlecode.com",
             "count": "790,026",
         },
+        {
+            "type": "bitbucket",
+            "info_url": "https://bitbucket.org",
+            "info": "public repositories from Bitbucket",
+            "search_pattern": "https://bitbucket.org/",
+            "visit_types": ["hg"],
+            "count": "336,795",
+        },
     ],
 }
 
@@ -294,7 +314,7 @@ def _swh_coverage(request):
         if origins_type not in listers_metrics:
             continue
 
-        count = sum(
+        count_total = sum(
             [metrics.origins_known for _, metrics in listers_metrics[origins_type]]
         )
         count_never_visited = sum(
@@ -303,9 +323,7 @@ def _swh_coverage(request):
                 for _, metrics in listers_metrics[origins_type]
             ]
         )
-        # CRAN origins are currently marked as not visited while they have been
-        if origins_type != "CRAN":
-            count -= count_never_visited
+        count = count_total - count_never_visited
 
         origins["count"] = f"{count:,}"
         origins["instances"] = defaultdict(dict)
