@@ -8,11 +8,10 @@ import uuid
 
 import pytest
 
-from django.contrib.auth.models import User
 from django.core.exceptions import ObjectDoesNotExist
 from django.utils import timezone
 
-from swh.web.auth.utils import SWH_AMBASSADOR_PERMISSION
+from swh.web.auth.utils import API_SAVE_ORIGIN_PERMISSION, SWH_AMBASSADOR_PERMISSION
 from swh.web.common.models import (
     SAVE_REQUEST_ACCEPTED,
     SAVE_REQUEST_PENDING,
@@ -35,6 +34,7 @@ from swh.web.tests.utils import (
     check_api_get_responses,
     check_api_post_response,
     check_api_post_responses,
+    create_django_permission,
 )
 
 pytestmark = pytest.mark.django_db
@@ -333,24 +333,7 @@ _visit_type = "git"
 _origin_url = "https://github.com/python/cpython"
 
 
-def test_save_requests_rate_limit(api_client, mocker):
-    create_save_origin_request = mocker.patch(
-        "swh.web.api.views.origin_save.create_save_origin_request"
-    )
-
-    def _save_request_dict(*args, **kwargs):
-        return {
-            "id": 1,
-            "visit_type": _visit_type,
-            "origin_url": _origin_url,
-            "save_request_date": datetime.now().isoformat(),
-            "save_request_status": SAVE_REQUEST_ACCEPTED,
-            "save_task_status": SAVE_TASK_NOT_YET_SCHEDULED,
-            "visit_date": None,
-            "visit_status": None,
-        }
-
-    create_save_origin_request.side_effect = _save_request_dict
+def test_save_requests_rate_limit(api_client, swh_scheduler):
 
     url = reverse(
         "api-1-save-origin",
@@ -363,6 +346,59 @@ def test_save_requests_rate_limit(api_client, mocker):
     check_api_post_response(api_client, url, status_code=429)
 
 
+def test_save_requests_no_rate_limit_if_permission(
+    api_client, regular_user, swh_scheduler
+):
+
+    regular_user.user_permissions.add(
+        create_django_permission(API_SAVE_ORIGIN_PERMISSION)
+    )
+
+    assert regular_user.has_perm(API_SAVE_ORIGIN_PERMISSION)
+
+    api_client.force_login(regular_user)
+
+    url = reverse(
+        "api-1-save-origin",
+        url_args={"visit_type": _visit_type, "origin_url": _origin_url},
+    )
+
+    for _ in range(save_origin_rate_post):
+        check_api_post_response(api_client, url, status_code=200)
+
+    check_api_post_response(api_client, url, status_code=200)
+
+
+def test_save_request_unknown_repo_with_permission(
+    api_client, regular_user, mocker, swh_scheduler
+):
+
+    regular_user.user_permissions.add(
+        create_django_permission(API_SAVE_ORIGIN_PERMISSION)
+    )
+
+    assert regular_user.has_perm(API_SAVE_ORIGIN_PERMISSION)
+
+    api_client.force_login(regular_user)
+
+    origin_url = "https://unkwownforge.org/user/repo"
+    check_created_save_request_status(
+        api_client,
+        mocker,
+        origin_url,
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_NOT_YET_SCHEDULED,
+    )
+    check_save_request_status(
+        api_client,
+        mocker,
+        swh_scheduler,
+        origin_url,
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_NOT_YET_SCHEDULED,
+    )
+
+
 def test_save_request_form_server_error(api_client, mocker):
     create_save_origin_request = mocker.patch(
         "swh.web.api.views.origin_save.create_save_origin_request"
@@ -524,20 +560,19 @@ def test_create_save_request_authenticated_user_id(
 
 
 def test_create_pending_save_request_multiple_authenticated_users(
-    api_client, swh_scheduler
+    api_client, swh_scheduler, regular_user, regular_user2
 ):
     origin_url = "https://some.git.hosters/user/repo3"
-    first_user = User.objects.create_user(username="first_user", password="")
-    second_user = User.objects.create_user(username="second_user", password="")
+
     url = reverse(
         "api-1-save-origin", url_args={"visit_type": "git", "origin_url": origin_url},
     )
 
-    api_client.force_login(first_user)
+    api_client.force_login(regular_user)
     check_api_post_response(api_client, url, status_code=200)
 
-    api_client.force_login(second_user)
+    api_client.force_login(regular_user2)
     check_api_post_response(api_client, url, status_code=200)
 
-    assert SaveOriginRequest.objects.get(user_ids__contains=f'"{first_user.id}"')
-    assert SaveOriginRequest.objects.get(user_ids__contains=f'"{second_user.id}"')
+    assert SaveOriginRequest.objects.get(user_ids__contains=f'"{regular_user.id}"')
+    assert SaveOriginRequest.objects.get(user_ids__contains=f'"{regular_user2.id}"')
